# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class UpdateFileRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'format': 'str',
        'format_edam': 'str',
        'life_cycle': 'FileLifeCycleSettings',
        'metadata': 'object',
        'add_metadata': 'object',
        'delete_metadata': 'object'
    }

    attribute_map = {
        'type': 'type',
        'format': 'format',
        'format_edam': 'formatEdam',
        'life_cycle': 'lifeCycle',
        'metadata': 'metadata',
        'add_metadata': 'addMetadata',
        'delete_metadata': 'deleteMetadata'
    }

    def __init__(self, type=None, format=None, format_edam=None, life_cycle=None, metadata=None, add_metadata=None, delete_metadata=None, local_vars_configuration=None):  # noqa: E501
        """UpdateFileRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._format = None
        self._format_edam = None
        self._life_cycle = None
        self._metadata = None
        self._add_metadata = None
        self._delete_metadata = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if format is not None:
            self.format = format
        if format_edam is not None:
            self.format_edam = format_edam
        if life_cycle is not None:
            self.life_cycle = life_cycle
        if metadata is not None:
            self.metadata = metadata
        if add_metadata is not None:
            self.add_metadata = add_metadata
        if delete_metadata is not None:
            self.delete_metadata = delete_metadata

    @property
    def type(self):
        """Gets the type of this UpdateFileRequest.  # noqa: E501

        The new file type (e.g. \"text/plain\").  # noqa: E501

        :return: The type of this UpdateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateFileRequest.

        The new file type (e.g. \"text/plain\").  # noqa: E501

        :param type: The type of this UpdateFileRequest.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def format(self):
        """Gets the format of this UpdateFileRequest.  # noqa: E501

        The File's Format  # noqa: E501

        :return: The format of this UpdateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this UpdateFileRequest.

        The File's Format  # noqa: E501

        :param format: The format of this UpdateFileRequest.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def format_edam(self):
        """Gets the format_edam of this UpdateFileRequest.  # noqa: E501

        The File's Edam Format  # noqa: E501

        :return: The format_edam of this UpdateFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._format_edam

    @format_edam.setter
    def format_edam(self, format_edam):
        """Sets the format_edam of this UpdateFileRequest.

        The File's Edam Format  # noqa: E501

        :param format_edam: The format_edam of this UpdateFileRequest.  # noqa: E501
        :type: str
        """

        self._format_edam = format_edam

    @property
    def life_cycle(self):
        """Gets the life_cycle of this UpdateFileRequest.  # noqa: E501


        :return: The life_cycle of this UpdateFileRequest.  # noqa: E501
        :rtype: FileLifeCycleSettings
        """
        return self._life_cycle

    @life_cycle.setter
    def life_cycle(self, life_cycle):
        """Sets the life_cycle of this UpdateFileRequest.


        :param life_cycle: The life_cycle of this UpdateFileRequest.  # noqa: E501
        :type: FileLifeCycleSettings
        """

        self._life_cycle = life_cycle

    @property
    def metadata(self):
        """Gets the metadata of this UpdateFileRequest.  # noqa: E501

        Metadata about this file and its contents  # noqa: E501

        :return: The metadata of this UpdateFileRequest.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this UpdateFileRequest.

        Metadata about this file and its contents  # noqa: E501

        :param metadata: The metadata of this UpdateFileRequest.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def add_metadata(self):
        """Gets the add_metadata of this UpdateFileRequest.  # noqa: E501

        Add an item to a metadata with array type  # noqa: E501

        :return: The add_metadata of this UpdateFileRequest.  # noqa: E501
        :rtype: object
        """
        return self._add_metadata

    @add_metadata.setter
    def add_metadata(self, add_metadata):
        """Sets the add_metadata of this UpdateFileRequest.

        Add an item to a metadata with array type  # noqa: E501

        :param add_metadata: The add_metadata of this UpdateFileRequest.  # noqa: E501
        :type: object
        """

        self._add_metadata = add_metadata

    @property
    def delete_metadata(self):
        """Gets the delete_metadata of this UpdateFileRequest.  # noqa: E501

        Delete an item from a metadata with array type  # noqa: E501

        :return: The delete_metadata of this UpdateFileRequest.  # noqa: E501
        :rtype: object
        """
        return self._delete_metadata

    @delete_metadata.setter
    def delete_metadata(self, delete_metadata):
        """Sets the delete_metadata of this UpdateFileRequest.

        Delete an item from a metadata with array type  # noqa: E501

        :param delete_metadata: The delete_metadata of this UpdateFileRequest.  # noqa: E501
        :type: object
        """

        self._delete_metadata = delete_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateFileRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateFileRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class VolumeFileListRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'volume_id': 'str',
        'file_ids': 'list[str]',
        'include_presigned_url': 'bool',
        'presigned_url_mode': 'str'
    }

    attribute_map = {
        'volume_id': 'volumeId',
        'file_ids': 'fileIds',
        'include_presigned_url': 'includePresignedUrl',
        'presigned_url_mode': 'presignedUrlMode'
    }

    def __init__(self, volume_id=None, file_ids=None, include_presigned_url=None, presigned_url_mode=None, local_vars_configuration=None):  # noqa: E501
        """VolumeFileListRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._volume_id = None
        self._file_ids = None
        self._include_presigned_url = None
        self._presigned_url_mode = None
        self.discriminator = None

        if volume_id is not None:
            self.volume_id = volume_id
        if file_ids is not None:
            self.file_ids = file_ids
        if include_presigned_url is not None:
            self.include_presigned_url = include_presigned_url
        if presigned_url_mode is not None:
            self.presigned_url_mode = presigned_url_mode

    @property
    def volume_id(self):
        """Gets the volume_id of this VolumeFileListRequest.  # noqa: E501

        Volume identifier  # noqa: E501

        :return: The volume_id of this VolumeFileListRequest.  # noqa: E501
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this VolumeFileListRequest.

        Volume identifier  # noqa: E501

        :param volume_id: The volume_id of this VolumeFileListRequest.  # noqa: E501
        :type: str
        """

        self._volume_id = volume_id

    @property
    def file_ids(self):
        """Gets the file_ids of this VolumeFileListRequest.  # noqa: E501

        File identifiers to list  # noqa: E501

        :return: The file_ids of this VolumeFileListRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this VolumeFileListRequest.

        File identifiers to list  # noqa: E501

        :param file_ids: The file_ids of this VolumeFileListRequest.  # noqa: E501
        :type: list[str]
        """

        self._file_ids = file_ids

    @property
    def include_presigned_url(self):
        """Gets the include_presigned_url of this VolumeFileListRequest.  # noqa: E501

        Optional parameter that returns presigned URL for each file when set to true  # noqa: E501

        :return: The include_presigned_url of this VolumeFileListRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_presigned_url

    @include_presigned_url.setter
    def include_presigned_url(self, include_presigned_url):
        """Sets the include_presigned_url of this VolumeFileListRequest.

        Optional parameter that returns presigned URL for each file when set to true  # noqa: E501

        :param include_presigned_url: The include_presigned_url of this VolumeFileListRequest.  # noqa: E501
        :type: bool
        """

        self._include_presigned_url = include_presigned_url

    @property
    def presigned_url_mode(self):
        """Gets the presigned_url_mode of this VolumeFileListRequest.  # noqa: E501

        Optional parameter to specify presigned url's content-disposition. If not specified, the browser will determine the default behavior.  Possible values: Attachment, Inline, Browser  # noqa: E501

        :return: The presigned_url_mode of this VolumeFileListRequest.  # noqa: E501
        :rtype: str
        """
        return self._presigned_url_mode

    @presigned_url_mode.setter
    def presigned_url_mode(self, presigned_url_mode):
        """Sets the presigned_url_mode of this VolumeFileListRequest.

        Optional parameter to specify presigned url's content-disposition. If not specified, the browser will determine the default behavior.  Possible values: Attachment, Inline, Browser  # noqa: E501

        :param presigned_url_mode: The presigned_url_mode of this VolumeFileListRequest.  # noqa: E501
        :type: str
        """

        self._presigned_url_mode = presigned_url_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeFileListRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeFileListRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FileListCopyRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_volume_id': 'str',
        'destination_folder_id': 'str',
        'ids': 'list[str]',
        'metadata_to_copy': 'list[str]',
        'duplicate_file_action': 'str'
    }

    attribute_map = {
        'source_volume_id': 'sourceVolumeId',
        'destination_folder_id': 'destinationFolderId',
        'ids': 'ids',
        'metadata_to_copy': 'metadataToCopy',
        'duplicate_file_action': 'duplicateFileAction'
    }

    def __init__(self, source_volume_id=None, destination_folder_id=None, ids=None, metadata_to_copy=None, duplicate_file_action=None, local_vars_configuration=None):  # noqa: E501
        """FileListCopyRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source_volume_id = None
        self._destination_folder_id = None
        self._ids = None
        self._metadata_to_copy = None
        self._duplicate_file_action = None
        self.discriminator = None

        self.source_volume_id = source_volume_id
        self.destination_folder_id = destination_folder_id
        self.ids = ids
        if metadata_to_copy is not None:
            self.metadata_to_copy = metadata_to_copy
        if duplicate_file_action is not None:
            self.duplicate_file_action = duplicate_file_action

    @property
    def source_volume_id(self):
        """Gets the source_volume_id of this FileListCopyRequest.  # noqa: E501

        The volume where the source files are copied from.  # noqa: E501

        :return: The source_volume_id of this FileListCopyRequest.  # noqa: E501
        :rtype: str
        """
        return self._source_volume_id

    @source_volume_id.setter
    def source_volume_id(self, source_volume_id):
        """Sets the source_volume_id of this FileListCopyRequest.

        The volume where the source files are copied from.  # noqa: E501

        :param source_volume_id: The source_volume_id of this FileListCopyRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source_volume_id is None:  # noqa: E501
            raise ValueError("Invalid value for `source_volume_id`, must not be `None`")  # noqa: E501

        self._source_volume_id = source_volume_id

    @property
    def destination_folder_id(self):
        """Gets the destination_folder_id of this FileListCopyRequest.  # noqa: E501

        The folder into which the source files will be copied.  # noqa: E501

        :return: The destination_folder_id of this FileListCopyRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_folder_id

    @destination_folder_id.setter
    def destination_folder_id(self, destination_folder_id):
        """Sets the destination_folder_id of this FileListCopyRequest.

        The folder into which the source files will be copied.  # noqa: E501

        :param destination_folder_id: The destination_folder_id of this FileListCopyRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and destination_folder_id is None:  # noqa: E501
            raise ValueError("Invalid value for `destination_folder_id`, must not be `None`")  # noqa: E501

        self._destination_folder_id = destination_folder_id

    @property
    def ids(self):
        """Gets the ids of this FileListCopyRequest.  # noqa: E501

        List of files ids to copy  # noqa: E501

        :return: The ids of this FileListCopyRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this FileListCopyRequest.

        List of files ids to copy  # noqa: E501

        :param ids: The ids of this FileListCopyRequest.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and ids is None:  # noqa: E501
            raise ValueError("Invalid value for `ids`, must not be `None`")  # noqa: E501

        self._ids = ids

    @property
    def metadata_to_copy(self):
        """Gets the metadata_to_copy of this FileListCopyRequest.  # noqa: E501


        :return: The metadata_to_copy of this FileListCopyRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._metadata_to_copy

    @metadata_to_copy.setter
    def metadata_to_copy(self, metadata_to_copy):
        """Sets the metadata_to_copy of this FileListCopyRequest.


        :param metadata_to_copy: The metadata_to_copy of this FileListCopyRequest.  # noqa: E501
        :type: list[str]
        """

        self._metadata_to_copy = metadata_to_copy

    @property
    def duplicate_file_action(self):
        """Gets the duplicate_file_action of this FileListCopyRequest.  # noqa: E501


        :return: The duplicate_file_action of this FileListCopyRequest.  # noqa: E501
        :rtype: str
        """
        return self._duplicate_file_action

    @duplicate_file_action.setter
    def duplicate_file_action(self, duplicate_file_action):
        """Sets the duplicate_file_action of this FileListCopyRequest.


        :param duplicate_file_action: The duplicate_file_action of this FileListCopyRequest.  # noqa: E501
        :type: str
        """

        self._duplicate_file_action = duplicate_file_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileListCopyRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileListCopyRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libconsole.configuration import Configuration


class PeriodUsageSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'start': 'datetime',
        'end': 'datetime',
        'i_credit': 'int',
        'total_usages': 'list[ProductUsage]',
        'user_aggregated_usages': 'list[UserAggregatedUsage]'
    }

    attribute_map = {
        'start': 'start',
        'end': 'end',
        'i_credit': 'iCredit',
        'total_usages': 'totalUsages',
        'user_aggregated_usages': 'userAggregatedUsages'
    }

    def __init__(self, start=None, end=None, i_credit=None, total_usages=None, user_aggregated_usages=None, local_vars_configuration=None):  # noqa: E501
        """PeriodUsageSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._start = None
        self._end = None
        self._i_credit = None
        self._total_usages = None
        self._user_aggregated_usages = None
        self.discriminator = None

        if start is not None:
            self.start = start
        if end is not None:
            self.end = end
        if i_credit is not None:
            self.i_credit = i_credit
        if total_usages is not None:
            self.total_usages = total_usages
        if user_aggregated_usages is not None:
            self.user_aggregated_usages = user_aggregated_usages

    @property
    def start(self):
        """Gets the start of this PeriodUsageSummary.  # noqa: E501


        :return: The start of this PeriodUsageSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this PeriodUsageSummary.


        :param start: The start of this PeriodUsageSummary.  # noqa: E501
        :type: datetime
        """

        self._start = start

    @property
    def end(self):
        """Gets the end of this PeriodUsageSummary.  # noqa: E501


        :return: The end of this PeriodUsageSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this PeriodUsageSummary.


        :param end: The end of this PeriodUsageSummary.  # noqa: E501
        :type: datetime
        """

        self._end = end

    @property
    def i_credit(self):
        """Gets the i_credit of this PeriodUsageSummary.  # noqa: E501


        :return: The i_credit of this PeriodUsageSummary.  # noqa: E501
        :rtype: int
        """
        return self._i_credit

    @i_credit.setter
    def i_credit(self, i_credit):
        """Sets the i_credit of this PeriodUsageSummary.


        :param i_credit: The i_credit of this PeriodUsageSummary.  # noqa: E501
        :type: int
        """

        self._i_credit = i_credit

    @property
    def total_usages(self):
        """Gets the total_usages of this PeriodUsageSummary.  # noqa: E501


        :return: The total_usages of this PeriodUsageSummary.  # noqa: E501
        :rtype: list[ProductUsage]
        """
        return self._total_usages

    @total_usages.setter
    def total_usages(self, total_usages):
        """Sets the total_usages of this PeriodUsageSummary.


        :param total_usages: The total_usages of this PeriodUsageSummary.  # noqa: E501
        :type: list[ProductUsage]
        """

        self._total_usages = total_usages

    @property
    def user_aggregated_usages(self):
        """Gets the user_aggregated_usages of this PeriodUsageSummary.  # noqa: E501


        :return: The user_aggregated_usages of this PeriodUsageSummary.  # noqa: E501
        :rtype: list[UserAggregatedUsage]
        """
        return self._user_aggregated_usages

    @user_aggregated_usages.setter
    def user_aggregated_usages(self, user_aggregated_usages):
        """Sets the user_aggregated_usages of this PeriodUsageSummary.


        :param user_aggregated_usages: The user_aggregated_usages of this PeriodUsageSummary.  # noqa: E501
        :type: list[UserAggregatedUsage]
        """

        self._user_aggregated_usages = user_aggregated_usages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PeriodUsageSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PeriodUsageSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libwes.configuration import Configuration


class WorkflowConnection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'type': 'str',
        'host': 'str',
        'host_validation_regex': 'str',
        'credentials': 'str',
        'options': 'str',
        'auto_disable_url': 'str',
        'auto_disable_http_method': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'host': 'host',
        'host_validation_regex': 'hostValidationRegex',
        'credentials': 'credentials',
        'options': 'options',
        'auto_disable_url': 'autoDisableUrl',
        'auto_disable_http_method': 'autoDisableHttpMethod'
    }

    def __init__(self, name=None, type=None, host=None, host_validation_regex=None, credentials=None, options=None, auto_disable_url=None, auto_disable_http_method=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowConnection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._type = None
        self._host = None
        self._host_validation_regex = None
        self._credentials = None
        self._options = None
        self._auto_disable_url = None
        self._auto_disable_http_method = None
        self.discriminator = None

        self.name = name
        if type is not None:
            self.type = type
        if host is not None:
            self.host = host
        if host_validation_regex is not None:
            self.host_validation_regex = host_validation_regex
        if credentials is not None:
            self.credentials = credentials
        if options is not None:
            self.options = options
        if auto_disable_url is not None:
            self.auto_disable_url = auto_disable_url
        if auto_disable_http_method is not None:
            self.auto_disable_http_method = auto_disable_http_method

    @property
    def name(self):
        """Gets the name of this WorkflowConnection.  # noqa: E501


        :return: The name of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowConnection.


        :param name: The name of this WorkflowConnection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 128):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this WorkflowConnection.  # noqa: E501

        Type of the connection: PlatformJwt, ApiBearerToken, AwsCredentials, ApiCustomAuthentication, BsshOAuthV2  # noqa: E501

        :return: The type of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this WorkflowConnection.

        Type of the connection: PlatformJwt, ApiBearerToken, AwsCredentials, ApiCustomAuthentication, BsshOAuthV2  # noqa: E501

        :param type: The type of this WorkflowConnection.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def host(self):
        """Gets the host of this WorkflowConnection.  # noqa: E501

        For API based connections, the Host part of the API endpoint  # noqa: E501

        :return: The host of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this WorkflowConnection.

        For API based connections, the Host part of the API endpoint  # noqa: E501

        :param host: The host of this WorkflowConnection.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                host is not None and len(host) > 1024):
            raise ValueError("Invalid value for `host`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                host is not None and len(host) < 0):
            raise ValueError("Invalid value for `host`, length must be greater than or equal to `0`")  # noqa: E501

        self._host = host

    @property
    def host_validation_regex(self):
        """Gets the host_validation_regex of this WorkflowConnection.  # noqa: E501

        Regex that hosts associated with this connection must meet (when host override by each run is allowed)  # noqa: E501

        :return: The host_validation_regex of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._host_validation_regex

    @host_validation_regex.setter
    def host_validation_regex(self, host_validation_regex):
        """Sets the host_validation_regex of this WorkflowConnection.

        Regex that hosts associated with this connection must meet (when host override by each run is allowed)  # noqa: E501

        :param host_validation_regex: The host_validation_regex of this WorkflowConnection.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                host_validation_regex is not None and len(host_validation_regex) > 100):
            raise ValueError("Invalid value for `host_validation_regex`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                host_validation_regex is not None and len(host_validation_regex) < 0):
            raise ValueError("Invalid value for `host_validation_regex`, length must be greater than or equal to `0`")  # noqa: E501

        self._host_validation_regex = host_validation_regex

    @property
    def credentials(self):
        """Gets the credentials of this WorkflowConnection.  # noqa: E501

        Credentials associated with the connection. Format depends on type of connection.  # noqa: E501

        :return: The credentials of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this WorkflowConnection.

        Credentials associated with the connection. Format depends on type of connection.  # noqa: E501

        :param credentials: The credentials of this WorkflowConnection.  # noqa: E501
        :type: str
        """

        self._credentials = credentials

    @property
    def options(self):
        """Gets the options of this WorkflowConnection.  # noqa: E501

        Comma separated list of options associated with the connection: CredentialsRequired, AllowCredentialsOverride, AutoDisableCredentialsAfterUse, AllowHostOverride  # noqa: E501

        :return: The options of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this WorkflowConnection.

        Comma separated list of options associated with the connection: CredentialsRequired, AllowCredentialsOverride, AutoDisableCredentialsAfterUse, AllowHostOverride  # noqa: E501

        :param options: The options of this WorkflowConnection.  # noqa: E501
        :type: str
        """

        self._options = options

    @property
    def auto_disable_url(self):
        """Gets the auto_disable_url of this WorkflowConnection.  # noqa: E501

        Relative URL (relative to Host) to call in order to disable the credentials  # noqa: E501

        :return: The auto_disable_url of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._auto_disable_url

    @auto_disable_url.setter
    def auto_disable_url(self, auto_disable_url):
        """Sets the auto_disable_url of this WorkflowConnection.

        Relative URL (relative to Host) to call in order to disable the credentials  # noqa: E501

        :param auto_disable_url: The auto_disable_url of this WorkflowConnection.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                auto_disable_url is not None and len(auto_disable_url) > 1024):
            raise ValueError("Invalid value for `auto_disable_url`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                auto_disable_url is not None and len(auto_disable_url) < 0):
            raise ValueError("Invalid value for `auto_disable_url`, length must be greater than or equal to `0`")  # noqa: E501

        self._auto_disable_url = auto_disable_url

    @property
    def auto_disable_http_method(self):
        """Gets the auto_disable_http_method of this WorkflowConnection.  # noqa: E501

        Http method to use to disable the credentials. Must be POST, PUT or DELETE  # noqa: E501

        :return: The auto_disable_http_method of this WorkflowConnection.  # noqa: E501
        :rtype: str
        """
        return self._auto_disable_http_method

    @auto_disable_http_method.setter
    def auto_disable_http_method(self, auto_disable_http_method):
        """Sets the auto_disable_http_method of this WorkflowConnection.

        Http method to use to disable the credentials. Must be POST, PUT or DELETE  # noqa: E501

        :param auto_disable_http_method: The auto_disable_http_method of this WorkflowConnection.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                auto_disable_http_method is not None and len(auto_disable_http_method) > 10):
            raise ValueError("Invalid value for `auto_disable_http_method`, length must be less than or equal to `10`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                auto_disable_http_method is not None and len(auto_disable_http_method) < 0):
            raise ValueError("Invalid value for `auto_disable_http_method`, length must be greater than or equal to `0`")  # noqa: E501

        self._auto_disable_http_method = auto_disable_http_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowConnection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowConnection):
            return True

        return self.to_dict() != other.to_dict()



import gzip
import logging
from contextlib import closing
from tempfile import NamedTemporaryFile
from typing import List
from urllib.parse import urlparse, urlunsplit, quote_plus, unquote_plus

import requests

from libica.app.projectops import ProjectOps
from libica.openapi.v2 import ApiException, ApiClient
from libica.openapi.v2.api.project_data_api import ProjectDataApi
from libica.openapi.v2.model.download import Download
from libica.openapi.v2.model.project import Project
from libica.openapi.v2.model.project_data import ProjectData
from libica.openapi.v2.model.project_data_paged_list import ProjectDataPagedList

logger = logging.getLogger(__name__)

URI_SCHEME = "icav2"


def to_uri(project_name: str, file_path: str) -> str:
    """Warning Experimental
    NOTE: this is still experimental and early adopter of the following proposal in discussion
    https://github.com/umccr-illumina/ica_v2/issues/96

    It mimics the GDS scheme as follows:
        THEN
            gds://volume_name/path/to/folder/file.txt
        NOW
            icav2://owning-project-name/path/to/folder/
            icav2://owning-project-name/path/to/file.txt
    """
    netloc = quote_plus(project_name, safe="/")
    path_ = quote_plus(file_path, safe="/")
    return urlunsplit((URI_SCHEME, netloc, path_, "", ""))


def from_uri(icav2_uri: str) -> tuple:
    """
    Inverse of to_uri()
    """
    if not icav2_uri.startswith(URI_SCHEME):
        raise ValueError(f"Unrecognised protocol scheme: {icav2_uri}")

    icav2_url_obj = urlparse(icav2_uri)
    return unquote_plus(icav2_url_obj.netloc), unquote_plus(icav2_url_obj.path)


class ProjectDataOpsFactory(ProjectOps):

    def __init__(self, api_client: ApiClient = None):
        super(ProjectDataOpsFactory, self).__init__(api_client=api_client)

    def from_uri(self, icav2_uri: str):
        project_name, path_ = from_uri(icav2_uri=icav2_uri)
        project = self.get_project_by_name(project_name=project_name)
        return ProjectDataOps(project_id=project.id, file_path=path_, api_client=self.api_client)


class ProjectDataOps(ProjectOps):
    """Usage:
    Create ProjectDataOps either using constructor or through available ProjectDataOpsFactory methods.

    Domain model UML class diagram is as follows:
        ProjectDataOps
            - private project: Project
            - private file_path: Any(str | List[str])

    The project property is bind at construction time that can't be changed after instantiated.
    The file_path property, however, is allowed to mutate throughout ProjectDataOps object life cycle.
    """

    def __init__(self, project_id: str, file_path=None, api_client: ApiClient = None):
        super(ProjectDataOps, self).__init__(api_client=api_client)
        self._project = self.get_project_by_id(project_id=project_id)
        self.__set_path(file_path=file_path)

    def __set_path(self, file_path):
        if file_path is None:
            self._file_path = []  # everything underneath of this project
        elif isinstance(file_path, str):
            self._file_path = [file_path]  # wrap str into list

    @property
    def project(self) -> Project:
        return self._project

    @property
    def file_path(self) -> List[str]:
        return self._file_path

    @file_path.setter
    def file_path(self, file_path):
        self.__set_path(file_path=file_path)

    def cd(self, file_path):
        self.__set_path(file_path=file_path)

    def check_path(self) -> list:
        """Use cases
        This behaves like UNIX `ls` command whereas you can check an absolute path to file or a directory.
        You can use it to check whether a file exist in ProjectData because it raises FileNotFoundError.
        Otherwise, it returns file(s) found.

        NOTE: This wrap list_files but more strict to raise FileNotFoundError if zero match.

        :return: List of ProjectData objects
        :rtype: list[ProjectData]
        """

        files = self.list_files()
        if len(files) == 0:
            raise FileNotFoundError(f"No file(s) found in project {self.project.name} at {self.file_path}")
        return files

    def get_file_to_bytes(self) -> bytes:
        """
        get_object_to_bytes API, with on-the-fly gzip detection and decompression

        :return bytes: bytes from the decompressed File body
        """
        file_path = self.file_path[0]
        try:
            ntf = self.download_file()
            if file_path.endswith(".gz"):
                obj_bytes = gzip.decompress(ntf.read())
            else:
                obj_bytes = ntf.read()
            ntf.close()
            return obj_bytes
        except Exception as e:
            message = f"Failed on reading the specified file in project {self.project.name} at {file_path}"
            raise FileNotFoundError(f"{message} Exception: {e}")

    def yield_data(self, page_size=1000):
        """Use cases
        Generator-based data lister for given project and paths.
        It will yield data by paginated chunks. Default page size chunk is 1000.
        If paths are not specified, it will return listing of all data under given project.
        Listing is recursive in nature for the path.
        The path can also be an absolute path for a data object.

        :param page_size:
        """

        with closing(self.api_client) as ctx_api_client:
            project_data_api: ProjectDataApi = ProjectDataApi(api_client=ctx_api_client)

            try:
                page_token = ""
                while True:
                    project_data_paged_list: ProjectDataPagedList = project_data_api.get_project_data_list(
                        project_id=self.project.id,
                        file_path=self.file_path,
                        page_size=str(page_size),
                        page_token=page_token,
                    )

                    yield project_data_paged_list.items

                    page_token = project_data_paged_list.next_page_token
                    if not project_data_paged_list.next_page_token:
                        break

            except ApiException as e:
                logger.error(e)

    def list_files(self, page_size=1000, suffix: str = "") -> list:
        """Use cases
        Get file listing for given project and paths.
        If paths are not specified, it will return listing of all files under given project.
        Listing is recursive in nature for folder path.
        You can still specify an absolute path for a file.

        :param page_size:
        :param suffix:
        :return: List of ProjectData objects
        :rtype: list[ProjectData]
        """
        items = []

        if suffix:
            for chunks in self.yield_data(page_size=page_size):
                for chunk in chunks:
                    project_data: ProjectData = chunk
                    if project_data.data.details is not None:
                        if str(project_data.data.details.path).endswith(suffix):
                            items.append(project_data)
        else:
            for chunks in self.yield_data(page_size=page_size):
                items.extend(chunks)

        return items

    def get_download_by_file_id(self, file_id) -> Download:
        with closing(self.api_client) as ctx_api_client:
            project_data_api: ProjectDataApi = ProjectDataApi(api_client=ctx_api_client)
            dl: Download = project_data_api.create_download_url_for_data(
                project_id=self.project.id,
                data_id=file_id,
            )
            return dl

    def get_download(self) -> (Download, None):
        file_path = self.file_path[0]

        logger.info(f"Downloading file from project {self.project.name} at {file_path}")

        file_list = self.list_files()

        if not len(file_list) == 1:
            logger.warning(f"Please specify a single file. "
                           f"Found {len(file_list)} files in project {self.project.name} at {file_path}")
            return None

        if len(file_list) == 0:
            logger.warning(f"File not found in in project {self.project.name} at {file_path}")
            return None

        prj_data: ProjectData = file_list[0]

        return self.get_download_by_file_id(prj_data.data.id)

    def create_presigned_url(self) -> str:
        return self.get_download().url

    def crete_presigned_url_by_file_id(self, file_id: str) -> (bool, str):
        try:
            dl = self.get_download_by_file_id(file_id)
            return True, dl.url
        except ApiException as e:
            message = f"Failed to sign the specified file {file_id} in project {self.project.name}. Exception - {e}"
            logger.error(message)
            return False, message

    def download_file(self) -> (NamedTemporaryFile, None):
        """Retrieve _single_ Project data file

        It collects matching path (one exact file) through list_files().
        Hence, there should only be one item in the list.
        Then, we use requests library to download the file from presigned URL to temporary storage.
        The downloaded file is back by NamedTemporaryFile and, therefore will be deleted once it goes 'out of scope'.

        NOTE:
        If multiple files are found, it warns and return None.

        It is recommended to close NamedTemporaryFile after use.
        For example, work within closing context manager like so.
            with closing(ntf) as f:
                with open(f.name, newline='') as csv_file:
                    csv_reader = csv.reader(csv_file, delimiter=',')
                    ...
                    ...

        :return NamedTemporaryFile: or None if file is not found or multiple files are found
        """
        presigned_url = self.create_presigned_url()

        req = requests.get(presigned_url)

        ntf = NamedTemporaryFile()
        with open(ntf.name, 'wb') as f:
            f.write(req.content)

        return ntf


class BundleDataOps:
    # TODO
    pass



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class CreateVolumeConfigurationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'provider_name': 'ObjectStorageProviderNames',
        'object_store_settings': 'ObjectStoreSettings',
        'restore_type': 'RestoreType'
    }

    attribute_map = {
        'name': 'name',
        'provider_name': 'providerName',
        'object_store_settings': 'objectStoreSettings',
        'restore_type': 'restoreType'
    }

    def __init__(self, name=None, provider_name=None, object_store_settings=None, restore_type=None, local_vars_configuration=None):  # noqa: E501
        """CreateVolumeConfigurationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._provider_name = None
        self._object_store_settings = None
        self._restore_type = None
        self.discriminator = None

        self.name = name
        if provider_name is not None:
            self.provider_name = provider_name
        self.object_store_settings = object_store_settings
        if restore_type is not None:
            self.restore_type = restore_type

    @property
    def name(self):
        """Gets the name of this CreateVolumeConfigurationRequest.  # noqa: E501

        Name for the volume configuration  # noqa: E501

        :return: The name of this CreateVolumeConfigurationRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateVolumeConfigurationRequest.

        Name for the volume configuration  # noqa: E501

        :param name: The name of this CreateVolumeConfigurationRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def provider_name(self):
        """Gets the provider_name of this CreateVolumeConfigurationRequest.  # noqa: E501


        :return: The provider_name of this CreateVolumeConfigurationRequest.  # noqa: E501
        :rtype: ObjectStorageProviderNames
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this CreateVolumeConfigurationRequest.


        :param provider_name: The provider_name of this CreateVolumeConfigurationRequest.  # noqa: E501
        :type: ObjectStorageProviderNames
        """

        self._provider_name = provider_name

    @property
    def object_store_settings(self):
        """Gets the object_store_settings of this CreateVolumeConfigurationRequest.  # noqa: E501


        :return: The object_store_settings of this CreateVolumeConfigurationRequest.  # noqa: E501
        :rtype: ObjectStoreSettings
        """
        return self._object_store_settings

    @object_store_settings.setter
    def object_store_settings(self, object_store_settings):
        """Sets the object_store_settings of this CreateVolumeConfigurationRequest.


        :param object_store_settings: The object_store_settings of this CreateVolumeConfigurationRequest.  # noqa: E501
        :type: ObjectStoreSettings
        """
        if self.local_vars_configuration.client_side_validation and object_store_settings is None:  # noqa: E501
            raise ValueError("Invalid value for `object_store_settings`, must not be `None`")  # noqa: E501

        self._object_store_settings = object_store_settings

    @property
    def restore_type(self):
        """Gets the restore_type of this CreateVolumeConfigurationRequest.  # noqa: E501


        :return: The restore_type of this CreateVolumeConfigurationRequest.  # noqa: E501
        :rtype: RestoreType
        """
        return self._restore_type

    @restore_type.setter
    def restore_type(self, restore_type):
        """Sets the restore_type of this CreateVolumeConfigurationRequest.


        :param restore_type: The restore_type of this CreateVolumeConfigurationRequest.  # noqa: E501
        :type: RestoreType
        """

        self._restore_type = restore_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVolumeConfigurationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVolumeConfigurationRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class VolumeLifeCycleSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'grace_period_days': 'int',
        'grace_period_end_action': 'GracePeriodEndAction'
    }

    attribute_map = {
        'grace_period_days': 'gracePeriodDays',
        'grace_period_end_action': 'gracePeriodEndAction'
    }

    def __init__(self, grace_period_days=None, grace_period_end_action=None, local_vars_configuration=None):  # noqa: E501
        """VolumeLifeCycleSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._grace_period_days = None
        self._grace_period_end_action = None
        self.discriminator = None

        if grace_period_days is not None:
            self.grace_period_days = grace_period_days
        if grace_period_end_action is not None:
            self.grace_period_end_action = grace_period_end_action

    @property
    def grace_period_days(self):
        """Gets the grace_period_days of this VolumeLifeCycleSettings.  # noqa: E501

        Number of days before the files associated to this volume expires  # noqa: E501

        :return: The grace_period_days of this VolumeLifeCycleSettings.  # noqa: E501
        :rtype: int
        """
        return self._grace_period_days

    @grace_period_days.setter
    def grace_period_days(self, grace_period_days):
        """Sets the grace_period_days of this VolumeLifeCycleSettings.

        Number of days before the files associated to this volume expires  # noqa: E501

        :param grace_period_days: The grace_period_days of this VolumeLifeCycleSettings.  # noqa: E501
        :type: int
        """

        self._grace_period_days = grace_period_days

    @property
    def grace_period_end_action(self):
        """Gets the grace_period_end_action of this VolumeLifeCycleSettings.  # noqa: E501


        :return: The grace_period_end_action of this VolumeLifeCycleSettings.  # noqa: E501
        :rtype: GracePeriodEndAction
        """
        return self._grace_period_end_action

    @grace_period_end_action.setter
    def grace_period_end_action(self, grace_period_end_action):
        """Sets the grace_period_end_action of this VolumeLifeCycleSettings.


        :param grace_period_end_action: The grace_period_end_action of this VolumeLifeCycleSettings.  # noqa: E501
        :type: GracePeriodEndAction
        """

        self._grace_period_end_action = grace_period_end_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeLifeCycleSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeLifeCycleSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FileUploadCompleteRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'multipart_upload_id': 'str',
        'part_etags': 'list[PartEtag]'
    }

    attribute_map = {
        'multipart_upload_id': 'multipartUploadId',
        'part_etags': 'partEtags'
    }

    def __init__(self, multipart_upload_id=None, part_etags=None, local_vars_configuration=None):  # noqa: E501
        """FileUploadCompleteRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._multipart_upload_id = None
        self._part_etags = None
        self.discriminator = None

        if multipart_upload_id is not None:
            self.multipart_upload_id = multipart_upload_id
        if part_etags is not None:
            self.part_etags = part_etags

    @property
    def multipart_upload_id(self):
        """Gets the multipart_upload_id of this FileUploadCompleteRequest.  # noqa: E501

        The multipart upload id used by the object store  # noqa: E501

        :return: The multipart_upload_id of this FileUploadCompleteRequest.  # noqa: E501
        :rtype: str
        """
        return self._multipart_upload_id

    @multipart_upload_id.setter
    def multipart_upload_id(self, multipart_upload_id):
        """Sets the multipart_upload_id of this FileUploadCompleteRequest.

        The multipart upload id used by the object store  # noqa: E501

        :param multipart_upload_id: The multipart_upload_id of this FileUploadCompleteRequest.  # noqa: E501
        :type: str
        """

        self._multipart_upload_id = multipart_upload_id

    @property
    def part_etags(self):
        """Gets the part_etags of this FileUploadCompleteRequest.  # noqa: E501

        etags for each uploaded part (optional for files that uses multipart upload)  # noqa: E501

        :return: The part_etags of this FileUploadCompleteRequest.  # noqa: E501
        :rtype: list[PartEtag]
        """
        return self._part_etags

    @part_etags.setter
    def part_etags(self, part_etags):
        """Sets the part_etags of this FileUploadCompleteRequest.

        etags for each uploaded part (optional for files that uses multipart upload)  # noqa: E501

        :param part_etags: The part_etags of this FileUploadCompleteRequest.  # noqa: E501
        :type: list[PartEtag]
        """

        self._part_etags = part_etags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileUploadCompleteRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileUploadCompleteRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Event Notification Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libens.configuration import Configuration


class CreateSubscriptionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'actions': 'list[str]',
        'name': 'str',
        'description': 'str',
        'filter_expression': 'str',
        'delivery_target': 'DeliveryTarget'
    }

    attribute_map = {
        'type': 'type',
        'actions': 'actions',
        'name': 'name',
        'description': 'description',
        'filter_expression': 'filterExpression',
        'delivery_target': 'deliveryTarget'
    }

    def __init__(self, type=None, actions=None, name=None, description=None, filter_expression=None, delivery_target=None, local_vars_configuration=None):  # noqa: E501
        """CreateSubscriptionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._actions = None
        self._name = None
        self._description = None
        self._filter_expression = None
        self._delivery_target = None
        self.discriminator = None

        self.type = type
        if actions is not None:
            self.actions = actions
        self.name = name
        if description is not None:
            self.description = description
        if filter_expression is not None:
            self.filter_expression = filter_expression
        self.delivery_target = delivery_target

    @property
    def type(self):
        """Gets the type of this CreateSubscriptionRequest.  # noqa: E501

        Event type which will be subscribed to  # noqa: E501

        :return: The type of this CreateSubscriptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateSubscriptionRequest.

        Event type which will be subscribed to  # noqa: E501

        :param type: The type of this CreateSubscriptionRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                type is not None and len(type) > 255):
            raise ValueError("Invalid value for `type`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                type is not None and len(type) < 1):
            raise ValueError("Invalid value for `type`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                type is not None and not re.search(r'^[a-zA-Z]+[.a-zA-Z]*$', type)):  # noqa: E501
            raise ValueError(r"Invalid value for `type`, must be a follow pattern or equal to `/^[a-zA-Z]+[.a-zA-Z]*$/`")  # noqa: E501

        self._type = type

    @property
    def actions(self):
        """Gets the actions of this CreateSubscriptionRequest.  # noqa: E501

        Actions which will be subscribed to for the event type  # noqa: E501

        :return: The actions of this CreateSubscriptionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this CreateSubscriptionRequest.

        Actions which will be subscribed to for the event type  # noqa: E501

        :param actions: The actions of this CreateSubscriptionRequest.  # noqa: E501
        :type: list[str]
        """

        self._actions = actions

    @property
    def name(self):
        """Gets the name of this CreateSubscriptionRequest.  # noqa: E501

        Name of the subscription  # noqa: E501

        :return: The name of this CreateSubscriptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateSubscriptionRequest.

        Name of the subscription  # noqa: E501

        :param name: The name of this CreateSubscriptionRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[a-zA-Z0-9]+[a-zA-Z0-9_-]*$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z0-9]+[a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this CreateSubscriptionRequest.  # noqa: E501

        Optional description for the subscription  # noqa: E501

        :return: The description of this CreateSubscriptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateSubscriptionRequest.

        Optional description for the subscription  # noqa: E501

        :param description: The description of this CreateSubscriptionRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 8192):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `8192`")  # noqa: E501

        self._description = description

    @property
    def filter_expression(self):
        """Gets the filter_expression of this CreateSubscriptionRequest.  # noqa: E501

        JSON-structured filter expression for events matching the subscription  # noqa: E501

        :return: The filter_expression of this CreateSubscriptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._filter_expression

    @filter_expression.setter
    def filter_expression(self, filter_expression):
        """Sets the filter_expression of this CreateSubscriptionRequest.

        JSON-structured filter expression for events matching the subscription  # noqa: E501

        :param filter_expression: The filter_expression of this CreateSubscriptionRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                filter_expression is not None and len(filter_expression) > 8192):
            raise ValueError("Invalid value for `filter_expression`, length must be less than or equal to `8192`")  # noqa: E501

        self._filter_expression = filter_expression

    @property
    def delivery_target(self):
        """Gets the delivery_target of this CreateSubscriptionRequest.  # noqa: E501


        :return: The delivery_target of this CreateSubscriptionRequest.  # noqa: E501
        :rtype: DeliveryTarget
        """
        return self._delivery_target

    @delivery_target.setter
    def delivery_target(self, delivery_target):
        """Sets the delivery_target of this CreateSubscriptionRequest.


        :param delivery_target: The delivery_target of this CreateSubscriptionRequest.  # noqa: E501
        :type: DeliveryTarget
        """
        if self.local_vars_configuration.client_side_validation and delivery_target is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_target`, must not be `None`")  # noqa: E501

        self._delivery_target = delivery_target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSubscriptionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateSubscriptionRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from libica.openapi.libtes.api.task_runs_api import TaskRunsApi
from libica.openapi.libtes.api.task_versions_api import TaskVersionsApi
from libica.openapi.libtes.api.tasks_api import TasksApi



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class ObjectStorageCredentialsResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_key': 'str',
        'secret_key': 'str',  # pragma: allowlist secret
        'session_token': 'str',
        'region': 'str',
        'bucket_name': 'str',
        'service_url': 'str',
        'upload_location': 'str',
        'expiration_date': 'datetime'
    }

    attribute_map = {
        'access_key': 'accessKey',
        'secret_key': 'secretKey',  # pragma: allowlist secret
        'session_token': 'sessionToken',
        'region': 'region',
        'bucket_name': 'bucketName',
        'service_url': 'serviceUrl',
        'upload_location': 'uploadLocation',
        'expiration_date': 'expirationDate'
    }

    def __init__(self, access_key=None, secret_key=None, session_token=None, region=None, bucket_name=None, service_url=None, upload_location=None, expiration_date=None, local_vars_configuration=None):  # noqa: E501
        """ObjectStorageCredentialsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_key = None
        self._secret_key = None
        self._session_token = None
        self._region = None
        self._bucket_name = None
        self._service_url = None
        self._upload_location = None
        self._expiration_date = None
        self.discriminator = None

        if access_key is not None:
            self.access_key = access_key
        if secret_key is not None:
            self.secret_key = secret_key
        if session_token is not None:
            self.session_token = session_token
        if region is not None:
            self.region = region
        if bucket_name is not None:
            self.bucket_name = bucket_name
        if service_url is not None:
            self.service_url = service_url
        if upload_location is not None:
            self.upload_location = upload_location
        if expiration_date is not None:
            self.expiration_date = expiration_date

    @property
    def access_key(self):
        """Gets the access_key of this ObjectStorageCredentialsResponse.  # noqa: E501

        Access key for use with AWS S3  # noqa: E501

        :return: The access_key of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this ObjectStorageCredentialsResponse.

        Access key for use with AWS S3  # noqa: E501

        :param access_key: The access_key of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def secret_key(self):
        """Gets the secret_key of this ObjectStorageCredentialsResponse.  # noqa: E501

        Secret key for use with AWS S3  # noqa: E501

        :return: The secret_key of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """Sets the secret_key of this ObjectStorageCredentialsResponse.

        Secret key for use with AWS S3  # noqa: E501

        :param secret_key: The secret_key of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._secret_key = secret_key

    @property
    def session_token(self):
        """Gets the session_token of this ObjectStorageCredentialsResponse.  # noqa: E501

        Token for use with AWS S3  # noqa: E501

        :return: The session_token of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._session_token

    @session_token.setter
    def session_token(self, session_token):
        """Sets the session_token of this ObjectStorageCredentialsResponse.

        Token for use with AWS S3  # noqa: E501

        :param session_token: The session_token of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._session_token = session_token

    @property
    def region(self):
        """Gets the region of this ObjectStorageCredentialsResponse.  # noqa: E501

        AWS region the folder will/does reside in  # noqa: E501

        :return: The region of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this ObjectStorageCredentialsResponse.

        AWS region the folder will/does reside in  # noqa: E501

        :param region: The region of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def bucket_name(self):
        """Gets the bucket_name of this ObjectStorageCredentialsResponse.  # noqa: E501

        AWS bucket the folder will/does reside in  # noqa: E501

        :return: The bucket_name of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this ObjectStorageCredentialsResponse.

        AWS bucket the folder will/does reside in  # noqa: E501

        :param bucket_name: The bucket_name of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._bucket_name = bucket_name

    @property
    def service_url(self):
        """Gets the service_url of this ObjectStorageCredentialsResponse.  # noqa: E501

        Service URL for multi-regional support  # noqa: E501

        :return: The service_url of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._service_url

    @service_url.setter
    def service_url(self, service_url):
        """Sets the service_url of this ObjectStorageCredentialsResponse.

        Service URL for multi-regional support  # noqa: E501

        :param service_url: The service_url of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._service_url = service_url

    @property
    def upload_location(self):
        """Gets the upload_location of this ObjectStorageCredentialsResponse.  # noqa: E501

        AWS upload location for this folder  # noqa: E501

        :return: The upload_location of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: str
        """
        return self._upload_location

    @upload_location.setter
    def upload_location(self, upload_location):
        """Sets the upload_location of this ObjectStorageCredentialsResponse.

        AWS upload location for this folder  # noqa: E501

        :param upload_location: The upload_location of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: str
        """

        self._upload_location = upload_location

    @property
    def expiration_date(self):
        """Gets the expiration_date of this ObjectStorageCredentialsResponse.  # noqa: E501

        expiration for temporary credentials  # noqa: E501

        :return: The expiration_date of this ObjectStorageCredentialsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this ObjectStorageCredentialsResponse.

        expiration for temporary credentials  # noqa: E501

        :param expiration_date: The expiration_date of this ObjectStorageCredentialsResponse.  # noqa: E501
        :type: datetime
        """

        self._expiration_date = expiration_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectStorageCredentialsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ObjectStorageCredentialsResponse):
            return True

        return self.to_dict() != other.to_dict()



"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p>   # noqa: E501

    The version of the OpenAPI document: 3
    Generated by: https://openapi-generator.tech
"""



class OpenApiException(Exception):
    """The base exception class for all OpenAPIExceptions"""


class ApiTypeError(OpenApiException, TypeError):
    def __init__(self, msg, path_to_item=None, valid_classes=None,
                 key_type=None):
        """ Raises an exception for TypeErrors

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list): a list of keys an indices to get to the
                                 current_item
                                 None if unset
            valid_classes (tuple): the primitive classes that current item
                                   should be an instance of
                                   None if unset
            key_type (bool): False if our value is a value in a dict
                             True if it is a key in a dict
                             False if our item is an item in a list
                             None if unset
        """
        self.path_to_item = path_to_item
        self.valid_classes = valid_classes
        self.key_type = key_type
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiTypeError, self).__init__(full_msg)


class ApiValueError(OpenApiException, ValueError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list) the path to the exception in the
                received_data dict. None if unset
        """

        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiValueError, self).__init__(full_msg)


class ApiAttributeError(OpenApiException, AttributeError):
    def __init__(self, msg, path_to_item=None):
        """
        Raised when an attribute reference or assignment fails.

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiAttributeError, self).__init__(full_msg)


class ApiKeyError(OpenApiException, KeyError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiKeyError, self).__init__(full_msg)


class ApiException(OpenApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


class NotFoundException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(NotFoundException, self).__init__(status, reason, http_resp)


class UnauthorizedException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(UnauthorizedException, self).__init__(status, reason, http_resp)


class ForbiddenException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(ForbiddenException, self).__init__(status, reason, http_resp)


class ServiceException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(ServiceException, self).__init__(status, reason, http_resp)


def render_path(path_to_item):
    """Returns a string representation of a path"""
    result = ""
    for pth in path_to_item:
        if isinstance(pth, int):
            result += "[{0}]".format(pth)
        else:
            result += "['{0}']".format(pth)
    return result



# flake8: noqa

"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p>   # noqa: E501

    The version of the OpenAPI document: 3
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from libica.openapi.v2.api_client import ApiClient

# import Configuration
from libica.openapi.v2.configuration import Configuration

# import exceptions
from libica.openapi.v2.exceptions import OpenApiException
from libica.openapi.v2.exceptions import ApiAttributeError
from libica.openapi.v2.exceptions import ApiTypeError
from libica.openapi.v2.exceptions import ApiValueError
from libica.openapi.v2.exceptions import ApiKeyError
from libica.openapi.v2.exceptions import ApiException



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libtes.configuration import Configuration


class Resources(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'size': 'str',
        'cpu_cores': 'float',
        'memory_gb': 'float',
        'hardware': 'list[str]',
        'tier': 'str'
    }

    attribute_map = {
        'type': 'type',
        'size': 'size',
        'cpu_cores': 'cpuCores',
        'memory_gb': 'memoryGb',
        'hardware': 'hardware',
        'tier': 'tier'
    }

    def __init__(self, type=None, size=None, cpu_cores=None, memory_gb=None, hardware=None, tier=None, local_vars_configuration=None):  # noqa: E501
        """Resources - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._size = None
        self._cpu_cores = None
        self._memory_gb = None
        self._hardware = None
        self._tier = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if size is not None:
            self.size = size
        if cpu_cores is not None:
            self.cpu_cores = cpu_cores
        if memory_gb is not None:
            self.memory_gb = memory_gb
        if hardware is not None:
            self.hardware = hardware
        if tier is not None:
            self.tier = tier

    @property
    def type(self):
        """Gets the type of this Resources.  # noqa: E501


        :return: The type of this Resources.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Resources.


        :param type: The type of this Resources.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def size(self):
        """Gets the size of this Resources.  # noqa: E501


        :return: The size of this Resources.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Resources.


        :param size: The size of this Resources.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def cpu_cores(self):
        """Gets the cpu_cores of this Resources.  # noqa: E501


        :return: The cpu_cores of this Resources.  # noqa: E501
        :rtype: float
        """
        return self._cpu_cores

    @cpu_cores.setter
    def cpu_cores(self, cpu_cores):
        """Sets the cpu_cores of this Resources.


        :param cpu_cores: The cpu_cores of this Resources.  # noqa: E501
        :type: float
        """

        self._cpu_cores = cpu_cores

    @property
    def memory_gb(self):
        """Gets the memory_gb of this Resources.  # noqa: E501


        :return: The memory_gb of this Resources.  # noqa: E501
        :rtype: float
        """
        return self._memory_gb

    @memory_gb.setter
    def memory_gb(self, memory_gb):
        """Sets the memory_gb of this Resources.


        :param memory_gb: The memory_gb of this Resources.  # noqa: E501
        :type: float
        """

        self._memory_gb = memory_gb

    @property
    def hardware(self):
        """Gets the hardware of this Resources.  # noqa: E501


        :return: The hardware of this Resources.  # noqa: E501
        :rtype: list[str]
        """
        return self._hardware

    @hardware.setter
    def hardware(self, hardware):
        """Sets the hardware of this Resources.


        :param hardware: The hardware of this Resources.  # noqa: E501
        :type: list[str]
        """

        self._hardware = hardware

    @property
    def tier(self):
        """Gets the tier of this Resources.  # noqa: E501


        :return: The tier of this Resources.  # noqa: E501
        :rtype: str
        """
        return self._tier

    @tier.setter
    def tier(self, tier):
        """Sets the tier of this Resources.


        :param tier: The tier of this Resources.  # noqa: E501
        :type: str
        """

        self._tier = tier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Resources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Resources):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Event Notification Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libens.configuration import Configuration


class Subscription(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'urn': 'str',
        'type': 'str',
        'actions': 'list[str]',
        'filter_expression': 'str',
        'name': 'str',
        'description': 'str',
        'delivery_target': 'DeliveryTarget',
        'match_identities': 'list[str]',
        'acl': 'list[str]',
        'tenant_id': 'str',
        'created_by_user_id': 'str',
        'time_created': 'datetime',
        'deleted_by_user_id': 'str',
        'time_deleted': 'datetime',
        'is_deleted': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'urn': 'urn',
        'type': 'type',
        'actions': 'actions',
        'filter_expression': 'filterExpression',
        'name': 'name',
        'description': 'description',
        'delivery_target': 'deliveryTarget',
        'match_identities': 'matchIdentities',
        'acl': 'acl',
        'tenant_id': 'tenantId',
        'created_by_user_id': 'createdByUserId',
        'time_created': 'timeCreated',
        'deleted_by_user_id': 'deletedByUserId',
        'time_deleted': 'timeDeleted',
        'is_deleted': 'isDeleted'
    }

    def __init__(self, id=None, urn=None, type=None, actions=None, filter_expression=None, name=None, description=None, delivery_target=None, match_identities=None, acl=None, tenant_id=None, created_by_user_id=None, time_created=None, deleted_by_user_id=None, time_deleted=None, is_deleted=None, local_vars_configuration=None):  # noqa: E501
        """Subscription - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._urn = None
        self._type = None
        self._actions = None
        self._filter_expression = None
        self._name = None
        self._description = None
        self._delivery_target = None
        self._match_identities = None
        self._acl = None
        self._tenant_id = None
        self._created_by_user_id = None
        self._time_created = None
        self._deleted_by_user_id = None
        self._time_deleted = None
        self._is_deleted = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if urn is not None:
            self.urn = urn
        if type is not None:
            self.type = type
        if actions is not None:
            self.actions = actions
        if filter_expression is not None:
            self.filter_expression = filter_expression
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if delivery_target is not None:
            self.delivery_target = delivery_target
        if match_identities is not None:
            self.match_identities = match_identities
        if acl is not None:
            self.acl = acl
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        if time_created is not None:
            self.time_created = time_created
        if deleted_by_user_id is not None:
            self.deleted_by_user_id = deleted_by_user_id
        if time_deleted is not None:
            self.time_deleted = time_deleted
        if is_deleted is not None:
            self.is_deleted = is_deleted

    @property
    def id(self):
        """Gets the id of this Subscription.  # noqa: E501

        Unique id of the subscription  # noqa: E501

        :return: The id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Subscription.

        Unique id of the subscription  # noqa: E501

        :param id: The id of this Subscription.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def urn(self):
        """Gets the urn of this Subscription.  # noqa: E501

        URN of the subscription  # noqa: E501

        :return: The urn of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this Subscription.

        URN of the subscription  # noqa: E501

        :param urn: The urn of this Subscription.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def type(self):
        """Gets the type of this Subscription.  # noqa: E501

        Type of event the subscription matches  # noqa: E501

        :return: The type of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Subscription.

        Type of event the subscription matches  # noqa: E501

        :param type: The type of this Subscription.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def actions(self):
        """Gets the actions of this Subscription.  # noqa: E501

        Types of actions the subscription matches for the event type  # noqa: E501

        :return: The actions of this Subscription.  # noqa: E501
        :rtype: list[str]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this Subscription.

        Types of actions the subscription matches for the event type  # noqa: E501

        :param actions: The actions of this Subscription.  # noqa: E501
        :type: list[str]
        """

        self._actions = actions

    @property
    def filter_expression(self):
        """Gets the filter_expression of this Subscription.  # noqa: E501

        JSON-structured filter expression for events matching the subscription  # noqa: E501

        :return: The filter_expression of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._filter_expression

    @filter_expression.setter
    def filter_expression(self, filter_expression):
        """Sets the filter_expression of this Subscription.

        JSON-structured filter expression for events matching the subscription  # noqa: E501

        :param filter_expression: The filter_expression of this Subscription.  # noqa: E501
        :type: str
        """

        self._filter_expression = filter_expression

    @property
    def name(self):
        """Gets the name of this Subscription.  # noqa: E501

        Name of the subscription  # noqa: E501

        :return: The name of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Subscription.

        Name of the subscription  # noqa: E501

        :param name: The name of this Subscription.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this Subscription.  # noqa: E501

        Optional description for the subscription  # noqa: E501

        :return: The description of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Subscription.

        Optional description for the subscription  # noqa: E501

        :param description: The description of this Subscription.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def delivery_target(self):
        """Gets the delivery_target of this Subscription.  # noqa: E501


        :return: The delivery_target of this Subscription.  # noqa: E501
        :rtype: DeliveryTarget
        """
        return self._delivery_target

    @delivery_target.setter
    def delivery_target(self, delivery_target):
        """Sets the delivery_target of this Subscription.


        :param delivery_target: The delivery_target of this Subscription.  # noqa: E501
        :type: DeliveryTarget
        """

        self._delivery_target = delivery_target

    @property
    def match_identities(self):
        """Gets the match_identities of this Subscription.  # noqa: E501

        ACL Identities for events the subscription matches  # noqa: E501

        :return: The match_identities of this Subscription.  # noqa: E501
        :rtype: list[str]
        """
        return self._match_identities

    @match_identities.setter
    def match_identities(self, match_identities):
        """Sets the match_identities of this Subscription.

        ACL Identities for events the subscription matches  # noqa: E501

        :param match_identities: The match_identities of this Subscription.  # noqa: E501
        :type: list[str]
        """

        self._match_identities = match_identities

    @property
    def acl(self):
        """Gets the acl of this Subscription.  # noqa: E501

        The list of identities that have access to this subscription  # noqa: E501

        :return: The acl of this Subscription.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this Subscription.

        The list of identities that have access to this subscription  # noqa: E501

        :param acl: The acl of this Subscription.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    @property
    def tenant_id(self):
        """Gets the tenant_id of this Subscription.  # noqa: E501

        Tenant id of the subscription owner  # noqa: E501

        :return: The tenant_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this Subscription.

        Tenant id of the subscription owner  # noqa: E501

        :param tenant_id: The tenant_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this Subscription.  # noqa: E501

        User id for the creator of the subscription  # noqa: E501

        :return: The created_by_user_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this Subscription.

        User id for the creator of the subscription  # noqa: E501

        :param created_by_user_id: The created_by_user_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._created_by_user_id = created_by_user_id

    @property
    def time_created(self):
        """Gets the time_created of this Subscription.  # noqa: E501

        Timestamp when the subscription was created  # noqa: E501

        :return: The time_created of this Subscription.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this Subscription.

        Timestamp when the subscription was created  # noqa: E501

        :param time_created: The time_created of this Subscription.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def deleted_by_user_id(self):
        """Gets the deleted_by_user_id of this Subscription.  # noqa: E501

        Id of the user who deleted the subscription, if applicable  # noqa: E501

        :return: The deleted_by_user_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._deleted_by_user_id

    @deleted_by_user_id.setter
    def deleted_by_user_id(self, deleted_by_user_id):
        """Sets the deleted_by_user_id of this Subscription.

        Id of the user who deleted the subscription, if applicable  # noqa: E501

        :param deleted_by_user_id: The deleted_by_user_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._deleted_by_user_id = deleted_by_user_id

    @property
    def time_deleted(self):
        """Gets the time_deleted of this Subscription.  # noqa: E501

        Timestamp when the subscription was deleted, if applicable  # noqa: E501

        :return: The time_deleted of this Subscription.  # noqa: E501
        :rtype: datetime
        """
        return self._time_deleted

    @time_deleted.setter
    def time_deleted(self, time_deleted):
        """Sets the time_deleted of this Subscription.

        Timestamp when the subscription was deleted, if applicable  # noqa: E501

        :param time_deleted: The time_deleted of this Subscription.  # noqa: E501
        :type: datetime
        """

        self._time_deleted = time_deleted

    @property
    def is_deleted(self):
        """Gets the is_deleted of this Subscription.  # noqa: E501

        Whether or not the subscription has been deleted  # noqa: E501

        :return: The is_deleted of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._is_deleted

    @is_deleted.setter
    def is_deleted(self, is_deleted):
        """Sets the is_deleted of this Subscription.

        Whether or not the subscription has been deleted  # noqa: E501

        :param is_deleted: The is_deleted of this Subscription.  # noqa: E501
        :type: bool
        """

        self._is_deleted = is_deleted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subscription):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Subscription):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from libica.openapi.libtes.api_client import ApiClient
from libica.openapi.libtes.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TaskVersionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_task_version(self, task_id, **kwargs):  # noqa: E501
        """Create a task version  # noqa: E501

        Creates a new task version within an existing task. Returns the ID associated with the new task version. Substitutions can be defined in the following format: \"{{string}}\", and specified at launch time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_task_version(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param CreateTaskVersionRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_task_version_with_http_info(task_id, **kwargs)  # noqa: E501

    def create_task_version_with_http_info(self, task_id, **kwargs):  # noqa: E501
        """Create a task version  # noqa: E501

        Creates a new task version within an existing task. Returns the ID associated with the new task version. Substitutions can be defined in the following format: \"{{string}}\", and specified at launch time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_task_version_with_http_info(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param CreateTaskVersionRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_task_version" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and ('task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `create_task_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in local_var_params:
            path_params['taskId'] = local_var_params['task_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tasks/{taskId}/versions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_task_version(self, task_id, version_id, **kwargs):  # noqa: E501
        """Get the details of a task version  # noqa: E501

        Gets details of a task version for a given task version ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_version(task_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str version_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_task_version_with_http_info(task_id, version_id, **kwargs)  # noqa: E501

    def get_task_version_with_http_info(self, task_id, version_id, **kwargs):  # noqa: E501
        """Get the details of a task version  # noqa: E501

        Gets details of a task version for a given task version ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_version_with_http_info(task_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str version_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_id',
            'version_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_task_version" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and ('task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `get_task_version`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['version_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `version_id` when calling `get_task_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in local_var_params:
            path_params['taskId'] = local_var_params['task_id']  # noqa: E501
        if 'version_id' in local_var_params:
            path_params['versionId'] = local_var_params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tasks/{taskId}/versions/{versionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def launch_task_run(self, task_id, version_id, **kwargs):  # noqa: E501
        """Launch a task version  # noqa: E501

        Launches a task version for a given task version ID. Returns the ID associated with the new task run. Substitutions defined in the task version must be specified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.launch_task_run(task_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str version_id: (required)
        :param LaunchTaskRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskRun
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.launch_task_run_with_http_info(task_id, version_id, **kwargs)  # noqa: E501

    def launch_task_run_with_http_info(self, task_id, version_id, **kwargs):  # noqa: E501
        """Launch a task version  # noqa: E501

        Launches a task version for a given task version ID. Returns the ID associated with the new task run. Substitutions defined in the task version must be specified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.launch_task_run_with_http_info(task_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str version_id: (required)
        :param LaunchTaskRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskRun, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_id',
            'version_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method launch_task_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and ('task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `launch_task_run`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['version_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `version_id` when calling `launch_task_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in local_var_params:
            path_params['taskId'] = local_var_params['task_id']  # noqa: E501
        if 'version_id' in local_var_params:
            path_params['versionId'] = local_var_params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tasks/{taskId}/versions/{versionId}:launch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskRun',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_task_versions(self, task_id, **kwargs):  # noqa: E501
        """Get a list of versions  # noqa: E501

        Gets a list of task versions within the given task accessible by the current tenant ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_task_versions(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str sort: Sort: Optional parameter to set the sort of the returned list. Valid fields include: name, version, timeCreated, timeModified.  The sort can be specified as asc or desc. (Default: asc.)
        :param str versions:
        :param str ids:
        :param str acls:
        :param int page_size: Optional parameter to define the page size returned. Valid inputs range from 1-1000.
        :param str page_token: pageToken: Optional parameter for navigation after initial listing. Valid values include firstPageToken,  nextPageToken, and previousPageToken (provided in the list response)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskVersionSummaryPagedItems
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_task_versions_with_http_info(task_id, **kwargs)  # noqa: E501

    def list_task_versions_with_http_info(self, task_id, **kwargs):  # noqa: E501
        """Get a list of versions  # noqa: E501

        Gets a list of task versions within the given task accessible by the current tenant ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_task_versions_with_http_info(task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str sort: Sort: Optional parameter to set the sort of the returned list. Valid fields include: name, version, timeCreated, timeModified.  The sort can be specified as asc or desc. (Default: asc.)
        :param str versions:
        :param str ids:
        :param str acls:
        :param int page_size: Optional parameter to define the page size returned. Valid inputs range from 1-1000.
        :param str page_token: pageToken: Optional parameter for navigation after initial listing. Valid values include firstPageToken,  nextPageToken, and previousPageToken (provided in the list response)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskVersionSummaryPagedItems, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_id',
            'sort',
            'versions',
            'ids',
            'acls',
            'page_size',
            'page_token'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_task_versions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and ('task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `list_task_versions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in local_var_params:
            path_params['taskId'] = local_var_params['task_id']  # noqa: E501

        query_params = []
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'versions' in local_var_params and local_var_params['versions'] is not None:  # noqa: E501
            query_params.append(('versions', local_var_params['versions']))  # noqa: E501
        if 'ids' in local_var_params and local_var_params['ids'] is not None:  # noqa: E501
            query_params.append(('ids', local_var_params['ids']))  # noqa: E501
        if 'acls' in local_var_params and local_var_params['acls'] is not None:  # noqa: E501
            query_params.append(('acls', local_var_params['acls']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501
        if 'page_token' in local_var_params and local_var_params['page_token'] is not None:  # noqa: E501
            query_params.append(('pageToken', local_var_params['page_token']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tasks/{taskId}/versions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskVersionSummaryPagedItems',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_task_version(self, task_id, version_id, **kwargs):  # noqa: E501
        """Update task version properties  # noqa: E501

        Update details of a task version for a given task version ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_task_version(task_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str version_id: (required)
        :param UpdateTaskVersionRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_task_version_with_http_info(task_id, version_id, **kwargs)  # noqa: E501

    def update_task_version_with_http_info(self, task_id, version_id, **kwargs):  # noqa: E501
        """Update task version properties  # noqa: E501

        Update details of a task version for a given task version ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_task_version_with_http_info(task_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_id: (required)
        :param str version_id: (required)
        :param UpdateTaskVersionRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskVersion, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_id',
            'version_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_task_version" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and ('task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `update_task_version`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['version_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `version_id` when calling `update_task_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_id' in local_var_params:
            path_params['taskId'] = local_var_params['task_id']  # noqa: E501
        if 'version_id' in local_var_params:
            path_params['versionId'] = local_var_params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/tasks/{taskId}/versions/{versionId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskVersion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    Event Notification Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from libica.openapi.libens.models.create_subscription_request import CreateSubscriptionRequest
from libica.openapi.libens.models.delivery_target import DeliveryTarget
from libica.openapi.libens.models.delivery_target_aws_sns_topic import DeliveryTargetAwsSnsTopic
from libica.openapi.libens.models.delivery_target_aws_sqs_queue import DeliveryTargetAwsSqsQueue
from libica.openapi.libens.models.delivery_target_workflow_run_launch import DeliveryTargetWorkflowRunLaunch
from libica.openapi.libens.models.error_response import ErrorResponse
from libica.openapi.libens.models.sort_direction import SortDirection
from libica.openapi.libens.models.subscription import Subscription
from libica.openapi.libens.models.subscription_list import SubscriptionList
from libica.openapi.libens.models.subscription_list_sort_fields import SubscriptionListSortFields



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libtes.configuration import Configuration


class Execution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'image': 'Image',
        'command': 'str',
        'args': 'list[str]',
        'inputs': 'list[InputMountMappingWithCreds]',
        'outputs': 'list[MountMappingWithCreds]',
        'system_files': 'SystemFiles',
        'environment': 'Environment',
        'working_directory': 'str',
        'retry_limit': 'int',
        'retry_count': 'int'
    }

    attribute_map = {
        'image': 'image',
        'command': 'command',
        'args': 'args',
        'inputs': 'inputs',
        'outputs': 'outputs',
        'system_files': 'systemFiles',
        'environment': 'environment',
        'working_directory': 'workingDirectory',
        'retry_limit': 'retryLimit',
        'retry_count': 'retryCount'
    }

    def __init__(self, image=None, command=None, args=None, inputs=None, outputs=None, system_files=None, environment=None, working_directory=None, retry_limit=3, retry_count=0, local_vars_configuration=None):  # noqa: E501
        """Execution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._image = None
        self._command = None
        self._args = None
        self._inputs = None
        self._outputs = None
        self._system_files = None
        self._environment = None
        self._working_directory = None
        self._retry_limit = None
        self._retry_count = None
        self.discriminator = None

        if image is not None:
            self.image = image
        if command is not None:
            self.command = command
        if args is not None:
            self.args = args
        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs
        if system_files is not None:
            self.system_files = system_files
        if environment is not None:
            self.environment = environment
        if working_directory is not None:
            self.working_directory = working_directory
        if retry_limit is not None:
            self.retry_limit = retry_limit
        if retry_count is not None:
            self.retry_count = retry_count

    @property
    def image(self):
        """Gets the image of this Execution.  # noqa: E501


        :return: The image of this Execution.  # noqa: E501
        :rtype: Image
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this Execution.


        :param image: The image of this Execution.  # noqa: E501
        :type: Image
        """

        self._image = image

    @property
    def command(self):
        """Gets the command of this Execution.  # noqa: E501


        :return: The command of this Execution.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this Execution.


        :param command: The command of this Execution.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def args(self):
        """Gets the args of this Execution.  # noqa: E501

        Argument to run specified task  # noqa: E501

        :return: The args of this Execution.  # noqa: E501
        :rtype: list[str]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this Execution.

        Argument to run specified task  # noqa: E501

        :param args: The args of this Execution.  # noqa: E501
        :type: list[str]
        """

        self._args = args

    @property
    def inputs(self):
        """Gets the inputs of this Execution.  # noqa: E501

        Path (Inputs) - Path to mount file at valid Url  URL (Inputs) - Url of file mounted at specified path  # noqa: E501

        :return: The inputs of this Execution.  # noqa: E501
        :rtype: list[InputMountMappingWithCreds]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this Execution.

        Path (Inputs) - Path to mount file at valid Url  URL (Inputs) - Url of file mounted at specified path  # noqa: E501

        :param inputs: The inputs of this Execution.  # noqa: E501
        :type: list[InputMountMappingWithCreds]
        """

        self._inputs = inputs

    @property
    def outputs(self):
        """Gets the outputs of this Execution.  # noqa: E501

        Path (Outputs) - Path where files will be output to valid Url  URL (Outputs) - Url of folder with files from the path will be uploaded  # noqa: E501

        :return: The outputs of this Execution.  # noqa: E501
        :rtype: list[MountMappingWithCreds]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this Execution.

        Path (Outputs) - Path where files will be output to valid Url  URL (Outputs) - Url of folder with files from the path will be uploaded  # noqa: E501

        :param outputs: The outputs of this Execution.  # noqa: E501
        :type: list[MountMappingWithCreds]
        """

        self._outputs = outputs

    @property
    def system_files(self):
        """Gets the system_files of this Execution.  # noqa: E501


        :return: The system_files of this Execution.  # noqa: E501
        :rtype: SystemFiles
        """
        return self._system_files

    @system_files.setter
    def system_files(self, system_files):
        """Sets the system_files of this Execution.


        :param system_files: The system_files of this Execution.  # noqa: E501
        :type: SystemFiles
        """

        self._system_files = system_files

    @property
    def environment(self):
        """Gets the environment of this Execution.  # noqa: E501


        :return: The environment of this Execution.  # noqa: E501
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this Execution.


        :param environment: The environment of this Execution.  # noqa: E501
        :type: Environment
        """

        self._environment = environment

    @property
    def working_directory(self):
        """Gets the working_directory of this Execution.  # noqa: E501


        :return: The working_directory of this Execution.  # noqa: E501
        :rtype: str
        """
        return self._working_directory

    @working_directory.setter
    def working_directory(self, working_directory):
        """Sets the working_directory of this Execution.


        :param working_directory: The working_directory of this Execution.  # noqa: E501
        :type: str
        """

        self._working_directory = working_directory

    @property
    def retry_limit(self):
        """Gets the retry_limit of this Execution.  # noqa: E501


        :return: The retry_limit of this Execution.  # noqa: E501
        :rtype: int
        """
        return self._retry_limit

    @retry_limit.setter
    def retry_limit(self, retry_limit):
        """Sets the retry_limit of this Execution.


        :param retry_limit: The retry_limit of this Execution.  # noqa: E501
        :type: int
        """

        self._retry_limit = retry_limit

    @property
    def retry_count(self):
        """Gets the retry_count of this Execution.  # noqa: E501


        :return: The retry_count of this Execution.  # noqa: E501
        :rtype: int
        """
        return self._retry_count

    @retry_count.setter
    def retry_count(self, retry_count):
        """Sets the retry_count of this Execution.


        :param retry_count: The retry_count of this Execution.  # noqa: E501
        :type: int
        """

        self._retry_count = retry_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Execution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Execution):
            return True

        return self.to_dict() != other.to_dict()
